import argparse
import logging

import hy

from .server import Server

logging.basicConfig(filename="/tmp/hyls.log", filemode="w", level=logging.DEBUG)
logging.getLogger('hyls')

def main():
    parser = argparse.ArgumentParser()
    parser.description = 'hy language server'

    parser.add_argument(
        '--version', action='store_true',
        help='Print version and exit'
    )

    args = parser.parse_args()

    if args.version:
        print('hy language server v0.0.1')
        return

    srv = Server()
    srv.start()

if __name__ == '__main__':
    main()



from setuptools import setup

with open('README.md', 'r') as f:
    long_description = f.read()

setup(
    name='hy-language-server',
    version='0.0.1',
    author='Rintaro Okamura',
    author_email='rintaro.okamura@gmail.com',
    description='hy language server using Jedhy',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/rinx/hy-language-server',
    packages=['hyls'],
    python_requires='>=3.6',
    install_requires=[
        'argparse',
        'hy',
        'pygls',
        'jedhy'
    ],
    entry_points={
        'console_scripts': [
            'hyls=hyls.__main__:main'
        ]
    }
)
